@@ -2,7 +2,7 @@ import os
 import stat
 
 
-def chmod(path, mode=stat.S_IRWXO):
+def chmod(path, mode=stat.S_IRWXU):
     path = os.path.realpath(path)
     print(f'Absolute path: {path}')
     if os.path.exists(path):
